@@ -1,7 +1,8 @@
 import click
 from pkg.utils import Config
 from pkg.constants import SYS_DEPLOYMENT_FILE_NAME_VALUE
-from pkg.src.helpers.helpers import DEPLOYMENT_REQUIRED_FIELDS, PIPELINE_REQUIRED_FIELDS
+from pkg.src.helpers.deployment_helpers import DEPLOYMENT_REQUIRED_FIELDS
+from pkg.src.helpers.pipeline_helpers import PIPELINE_REQUIRED_FIELDS
 
 
 # General
@@ -77,19 +78,26 @@ LABELS_FILTER = click.option('-lb', '--labels', required=False, default=None, ty
                              metavar='<key1:value,key2:value>', help="Labels defined as key/value pairs")
 
 
-# Deployment version variables
+# Deployment/pipeline version variables
 VERSION_NAME_ARGUMENT = click.argument('version_name', required=True, metavar='<version_name>', nargs=1)
 VERSION_NAME_OPTION = click.option('-v', '--version_name', required=True, metavar='<name>',
                                    help="The version name")
 VERSION_NAME_OPTIONAL = click.option('-v', '--version_name', required=False, metavar='<name>', default=None,
                                      help="The version name")
+DEPLOYMENT_VERSION_OPTIONAL = click.option('-dv', '--deployment_version_name', required=False, metavar='<name>',
+                                           default=None, help="The deployment version name")
+PIPELINE_VERSION_OPTIONAL = click.option('-pv', '--pipeline_version_name', required=False, metavar='<name>',
+                                         default=None, help="The pipeline version name")
+
+VERSION_DEFAULT_UPDATE = click.option('-default', '--default_version', required=False, default=None,
+                                      help="The name of the version that should become the default", metavar='<name>')
 VERSION_NAME_UPDATE = click.option('-n', '--new_name', required=False, default=None,
                                    help="The new version name", metavar='<name>')
 VERSION_NAME_ZIP = click.option('-v', '--version_name', required=False, default=None, metavar='<name>',
                                 help="The version name used in the ZIP filename")
 VERSION_NAME_OVERRULE = click.argument('version_name', required=False, default=None, metavar='<version_name>', nargs=1)
 VERSION_YAML_FILE = click.option("-f", "--yaml_file", required=False, default=None, type=click.Path(), metavar='<path>',
-                                 help="Path to a yaml file that contains deployment options")
+                                 help="Path to a yaml file that contains version options")
 VERSION_YAML_OUTPUT = click.option('-o', '--output_path', required=False, default=None, metavar='<path>',
                                    help="Path to file or directory to store version yaml file")
 
@@ -103,6 +111,11 @@ MAX_INSTANCES = click.option('-max', '--maximum_instances', required=False, defa
                              help="Maximum number of instances")
 MAX_IDLE_TIME = click.option('-t', '--maximum_idle_time', required=False, default=None, type=int, metavar='<int>',
                              help="Maximum idle time before shutting down instance (seconds)")
+RETENTION_MODE = click.option('-rtm', '--request_retention_mode', required=False, default=None,
+                              type=click.Choice(['none', 'metadata', 'full'], case_sensitive=False), show_default=True,
+                              help="Mode of request retention for requests to the version")
+RETENTION_TIME = click.option('-rtt', '--request_retention_time', required=False, default=None, type=int,
+                              metavar='<int>', help="Number of seconds to store requests to the version")
 
 VERSION_LABELS = click.option('-lb', '--labels', 'version_labels', required=False, default=None, multiple=True,
                               type=str, metavar='<key1:value,key2:value>', help="Labels defined as key/value pairs")
@@ -144,6 +157,8 @@ REQUEST_DATA_UPDATE = click.option('--data', required=False, help="The new input
                                    metavar='<string>')
 REQUEST_DATA_MULTI = click.option('--data', required=True, help="The input data of the request",
                                   metavar='<string>', multiple=True)
+REQUEST_BATCH = click.option('--batch', required=False, default=False, is_flag=True,
+                             help="Whether you want to perform the request as batch request (async)")
 REQUEST_ID_MULTI = click.option('-id', '--request_id', required=True, metavar='<id>', multiple=True,
                                 help="The ID of the request")
 REQUEST_ID_OPTIONAL = click.option('-id', '--request_id', required=False, default=None, metavar='<id>',
@@ -171,7 +186,8 @@ BLOB_TTL = click.option('-ttl', '--time_to_live', 'ttl', required=False, default
                         help="The time to live of the blob in seconds (default = 259200 seconds, 3 days)")
 
 # Pipelines
-PIPELINE_NAME = click.argument('pipeline_name', required=True, metavar='<name>', nargs=1)
+PIPELINE_NAME_ARGUMENT = click.argument('pipeline_name', required=True, metavar='<pipeline_name>', nargs=1)
+PIPELINE_NAME_OPTION = click.option('-p', '--pipeline_name', required=True, metavar='<name>', help="The pipeline name")
 PIPELINE_NAME_OPTIONAL = click.option('-p', '--pipeline_name', required=False, default=None, metavar='<name>',
                                       help="The pipeline name")
 PIPELINE_NAME_OVERRULE = click.argument('pipeline_name', required=False, default=None, metavar='<name>', nargs=1)
